@@ -293,7 +293,7 @@ def ComputeMSE(y_test: torch.Tensor, y_pred: torch.Tensor) -> torch.Tensor:
     if y_pred.dtype is not _DTYPE:
         y_pred = torch.as_tensor(y_pred, dtype = _DTYPE)
             
-    return torch.mean((y_test-y_pred)**2, dim = 1)
+    return torch.mean((y_test-y_pred)**2, dim = 0)
 #--------------------------------------------------------------------------
 def ComputeR2(y_test: torch.Tensor, y_pred: torch.Tensor) -> torch.Tensor:
     '''
@@ -517,12 +517,8 @@ def ReadStudy(filepath: str, study_parameters: Union[list,tuple], nstudy: int =
                 study_dict = {}
                 G_study = G_esn_id.get(str(istudy))
 
-                if mse_is_array:                                                         #20.10.21: if mse was saved as array, this can now be read
-                    mse_train.append(np.array(G_study.get('mse_train')))
-                    mse_train.append(np.array(G_study.get('mse_test')))
-                else:
-                    mse_train.append(G_study.attrs['mse_train'])
-                    mse_test.append(G_study.attrs['mse_test'])
+                mse_train.append(np.array(G_study.get('mse_train')))
+                mse_train.append(np.array(G_study.get('mse_test')))
 
                 if read_pred:
                     y_pred.append(np.array(G_study.get('y_pred')))
@@ -559,12 +555,9 @@ def ReadStudy(filepath: str, study_parameters: Union[list,tuple], nstudy: int =
                             study_dict[name] = G_study.attrs[name]
                         study_dicts.append(study_dict)
             
-                    if mse_is_array:
-                        MSE_train.append(np.array(G_study.get('mse_train')))
-                        MSE_test.append(np.array(G_study.get('mse_test')))
-                    else: 
-                        MSE_train.append(G_study.attrs['mse_train'])
-                        MSE_test.append(G_study.attrs['mse_test'])
+                    MSE_train.append(np.array(G_study.get('mse_train')))
+                    MSE_test.append(np.array(G_study.get('mse_test')))
+
 
                     if readPred:
                         Y_pred.append(np.array(G_study.get('y_pred')))
